==> gregtech-5.10.21.1-sources.jar: gregtech/loaders/preload/GT_Loader_OreProcessing.java <==
package gregtech.loaders.preload;

import gregtech.api.util.GT_Log;
import gregtech.loaders.oreprocessing.*;

public class GT_Loader_OreProcessing
        implements Runnable {
    public void run() {
        GT_Log.out.println("GT_Mod: Register Ore processing.");
        new ProcessingAll();
        new ProcessingArrows();
        new ProcessingBattery();
        new ProcessingBeans();
        new ProcessingBlock();
        new ProcessingBolt();
        new ProcessingCell();
        new ProcessingCellPlasma();
        new ProcessingCircuit();
        new ProcessingCompressed();
        new ProcessingCrafting();
        new ProcessingCrop();
        new ProcessingCrushedPurified();
        new ProcessingCrushedCentrifuged();
        new ProcessingCrystallized();
        new ProcessingDirty();
        new ProcessingDust();
        new ProcessingDustImpure();
        new ProcessingDustSmall();
        new ProcessingDustTiny();
        new ProcessingDye();
        new ProcessingFoil();
        new ProcessingFood();
        new ProcessingLens();
        new ProcessingShaping();
        new ProcessingGemChipped();
        new ProcessingGemFlawed();
        new ProcessingGem();
        new ProcessingGemFlawless();
        new ProcessingGemExquisite();
        new ProcessingGear();
        new ProcessingGearSmall();
        new ProcessingIngot1();
        new ProcessingIngot2();
        new ProcessingIngot3();
        new ProcessingIngot4();
        new ProcessingIngot5();
        new ProcessingIngotHot();
        new ProcessingItem();
        new ProcessingLeaves();
        new ProcessingLog();
        new ProcessingTransforming();
        new ProcessingNugget();
        new ProcessingOre();
        new ProcessingOrePoor();
        new ProcessingOreSmelting();
        new ProcessingPipeSmall();
        new ProcessingPipeMedium();
        new ProcessingPipeLarge();
        new ProcessingPipeRestrictive();
        new ProcessingPlank();
        new ProcessingPlate1();
        new ProcessingPlate2();
        new ProcessingPlate3();
        new ProcessingPlate4();
        new ProcessingPlate5();
        new ProcessingPlate9();
        new ProcessingPlateAlloy();
        new ProcessingPure();
        new ProcessingRecycling();
        new ProcessingSand();
        new ProcessingSaplings();
        new ProcessingSlab();
        new ProcessingStick();
        new ProcessingStickLong();
        new ProcessingStone();
        new ProcessingStoneCobble();
        new ProcessingStoneVarious();
        new ProcessingToolHeadArrow();
        new ProcessingToolHeadAxe();
        new ProcessingToolHeadBuzzSaw();
        new ProcessingToolHeadFile();
        new ProcessingToolHeadHammer();
        new ProcessingToolHeadHoe();
        new ProcessingToolHeadPickaxe();
        new ProcessingToolHeadSaw();
        new ProcessingToolHeadSense();
        new ProcessingToolHeadShovel();
        new ProcessingToolHeadSword();
        new ProcessingToolHeadPlow();
        new ProcessingToolHeadDrill();
        new ProcessingToolHeadChainsaw();
        new ProcessingToolHeadWrench();
        new ProcessingToolHeadUniversalSpade();
        new ProcessingWax();
        new ProcessingWire01();
        new ProcessingWire02();
        new ProcessingWire04();
        new ProcessingWire08();
        new ProcessingWire12();
        new ProcessingWire16();
    }
}

==> gregtech-5.10.32-sources.jar: gregtech/loaders/preload/GT_Loader_OreProcessing.java <==
package gregtech.loaders.preload;

import gregtech.api.util.GT_Log;
import gregtech.loaders.oreprocessing.*;

public class GT_Loader_OreProcessing
        implements Runnable {
    public void run() {
        GT_Log.out.println("GT_Mod: Register Ore processing.");
        new ProcessingAll();
        new ProcessingArrows();
        new ProcessingBeans();
        new ProcessingBlock();
        new ProcessingBolt();
        new ProcessingCell();
        new ProcessingCrate();
        new ProcessingCircuit();
        new ProcessingCompressed();
        new ProcessingCrafting();
        new ProcessingCrop();
        new ProcessingCrushedOre();
        new ProcessingCrystallized();
        new ProcessingDirty();
        new ProcessingDust();
        new ProcessingDye();
        new ProcessingFoil();
        new ProcessingFineWire();
        new ProcessingFood();
        new ProcessingLens();
        new ProcessingShaping();
        new ProcessingGem();
        new ProcessingGear();
        new ProcessingIngot();
        new ProcessingItem();
        new ProcessingLog();
        new ProcessingTransforming();
        new ProcessingNugget();
        new ProcessingOre();
        new ProcessingOrePoor();
        new ProcessingOreSmelting();
        new ProcessingPipe();
        new ProcessingPlank();
        new ProcessingPlate();
        new ProcessingPure();
        new ProcessingRecycling();
        new ProcessingRound();
        new ProcessingRotor();
        new ProcessingSand();
        new ProcessingSaplings();
        new ProcessingScrew();
        new ProcessingSlab();
        new ProcessingStick();
        new ProcessingStickLong();
        new ProcessingStone();
        new ProcessingStoneCobble();
        new ProcessingStoneVarious();
        new ProcessingToolHead();
        new ProcessingToolOther();
        new ProcessingWax();
        new ProcessingWire();
    }
}
